@@ -8,8 +8,8 @@ use base qw{ Module::Build };
 use Carp;
 use File::Spec;
 
-my @optionals_dir = qw{ xt optionals };
-my @hide = qw{ Time::HiRes };
+my @optionals_dir = qw{ xt author optionals };
+my @hide = qw{ SOAP::Lite Time::HiRes };
 
 {
     my $done;
@@ -105,7 +105,7 @@ sub ACTION_authortest {
     my @depends_on = ( qw{ build make_optional_modules_tests } );
     -e 'META.yml' or push @depends_on, 'distmeta';
     $self->depends_on( @depends_on );
-    my @test_files = qw{ t xt };
+    my @test_files = qw{ t xt/author };
     my $optdir = File::Spec->catdir( @optionals_dir );
     -d $optdir and push @test_files, $optdir;
     $self->test_files( @test_files );
